@@ -133,7 +133,7 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True,
     print(f"\n--> Extracted data saved in data_dict[{new_key}], see head below:")
     display(HTML(ts_df.head().to_html()))
     data_counter += 1
-    # print(ts_df[target].head())
+
     freq, _ = interval_to_freq(time_interval)
 
     ########## This is where we start the loading of the data file ######################
@@ -192,10 +192,10 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True,
     x_label = f'Datetime'
     y_label = f"Total Demand (MW)"
 
-    # ts_plot(ts_df, ts_column, target,
-    #         title=title,
-    #         y_label=y_label
-    #         )
+    ts_plot(ts_df, ts_column, target,
+            title=title,
+            y_label=y_label
+            )
 
     print("\n\n-------------------------------------------------------------------")
     print("STEP 4) EDA II (Time-Series Stats)")
@@ -209,15 +209,15 @@ def make_ts_magic(data, ts_column, sep=',', target=None, univarate=True,
     # ets = ets_decomposition_plot(ts_df, ts_column, target, title, y_label);
     # ets = ets_decomposition_plot(ts_df, ts_column, target, title, y_label,
     #                        prophet=True);
-    # ets = ets_decomposition_plot(ts_df, ts_column, target, title, y_label,
-    #                              plotly=True);
+    ets = ets_decomposition_plot(ts_df, ts_column, target, title, y_label,
+                                 plotly=True);
 
     print("Plot out ACF/PACF graph..\n")
     title = "Total Electricity Demand"
     lags_7 = 24*7  # 7-days lag
     lags_30 = 24*30  # 30-days lag
     lags_90 = 24*90  # 90-days lag
-    # acf_pacf_plot(ts_df, target, title, lags=[lags_7, lags_30])
+    acf_pacf_plot(ts_df, target, title, lags=[lags_7, lags_30])
 
     print("4.4) Expotential Smoothing Holt-Winters.\n")
 
